..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

===============================
Welcome to Zun's documentation!
===============================
Zun is an OpenStack Container service. It aims to provide an OpenStack API for
provisioning and managing containerized workload on OpenStack.

Admin Guide
~~~~~~~~~~~
.. toctree::
   :maxdepth: 1

   admin/index

Contributor Guide
~~~~~~~~~~~~~~~~~
.. toctree::
   :glob:
   :maxdepth: 2

   contributor/index

Installation Guide
~~~~~~~~~~~~~~~~~~
.. toctree::
   :maxdepth: 1

   install/index

Command Line Guide
~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   cli/index

Configuration Guide
~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   configuration/index

Architecture Concepts
~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   user/filter-scheduler

Indices and tables
~~~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`search`
